from simplenlp.euro import StemmedEuroNL

def NL():
    return StemmedEuroNL('nl', exceptions={})
